@@ -12,6 +12,8 @@ use constant proc => {
     cpuinfo  => '/proc/cpuinfo', # cpu information
     uptime   => '/proc/uptime',  # uptime file
     version  => '/proc/version', # os version
+    meminfo  => '/proc/meminfo',
+    swaps    => '/proc/swaps',
     fstab    => '/etc/fstab',    # for filesystem type of the current disk
     resolv   => '/etc/resolv.conf',
     timezone => '/etc/timezone',
